@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 """
 This test will initialize the display using displayio and draw a solid green
 background, a smaller purple rectangle, and some yellow text.
@@ -23,7 +26,7 @@ display_bus = displayio.FourWire(
 display = SSD1351(display_bus, width=128, height=96)
 
 # Make the display context
-splash = displayio.Group(max_size=10)
+splash = displayio.Group()
 display.show(splash)
 
 color_bitmap = displayio.Bitmap(128, 96, 1)
